@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2001-2013 Free Software Foundation, Inc.
+# Copyright (C) 2001-2020 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Test of subdir make distclean rules.
 # From Robert Collins.
@@ -21,7 +21,7 @@ required=cc
 . test-init.sh
 
 cat >> configure.ac << 'END'
-AM_PROG_CC_C_O
+AC_PROG_CC
 AC_OUTPUT
 END
 
